django_auxilium.callback_mail.filebased module
==============================================

.. automodule:: django_auxilium.callback_mail.filebased
    :members:
    :undoc-members:
    :show-inheritance:
